# Gradec
A Python library for meta-analytic functional decoding of cortical gradient of functional 
connectivity.

[![License](https://img.shields.io/badge/license-Apache--2.0-blue.svg)](https://opensource.org/license/apache-2-0)
[![Test Status](https://github.com/JulioAPeraza/gradec/actions/workflows/testing.yml/badge.svg)](https://github.com/JulioAPeraza/gradec/actions/workflows/testing.yml)
[![codecov](https://codecov.io/gh/JulioAPeraza/gradec/branch/main/graph/badge.svg?token=JTEHFX20B1)](https://codecov.io/gh/JulioAPeraza/gradec)
[![Documentation Status](https://readthedocs.org/projects/gradec/badge/?version=latest)](https://gradec.readthedocs.io/en/latest/)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)

Currently, gradec implements a range of gradient segmentation, and meta-analytic decoding algorithms.

## Installation

Please see our [installation instructions](https://gradec.readthedocs.io/en/stable/installation.html)
for information on how to install gradec.

### Installation with pip
```
pip install gradec
```

### Local installation (development version)
```
pip install git+https://github.com/JulioAPeraza/gradec.git
```

## Citing gradec

If you use gradec in your research, we recommend citing the Zenodo DOI associated with the gradec version you used.
You can find the Zenodo DOI associated with each gradec release at .

## Contributing

Please see our [contributing guidelines](https://github.com/JulioAPeraza/gradec/blob/main/CONTRIBUTING.md)
for more information on contributing to gradec.

We ask that all contributions to `gradec` respect our [code of conduct](https://github.com/JulioAPeraza/gradec/blob/main/CODE_OF_CONDUCT.md).
